@@ -1,9 +1,12 @@
 use strict;
 use warnings;
-package Plack::App::BeanstalkConsole; # git description: v0.007-12-g5fc6cf4
-# ABSTRACT: a web application that provides access to Beanstalk statistics and tools
+package Plack::App::BeanstalkConsole; # git description: v0.008-22-gc4d13f8
+# ABSTRACT: A web application that provides access to Beanstalk statistics and tools
 # KEYWORDS: beanstalk jobs queue web application dashboard console plack psgi
-$Plack::App::BeanstalkConsole::VERSION = '0.008';
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.009';
+
 use parent 'Plack::App::PHPCGIFile';
 
 use File::ShareDir ();
@@ -47,11 +50,11 @@ __END__
 
 =head1 NAME
 
-Plack::App::BeanstalkConsole - a web application that provides access to Beanstalk statistics and tools
+Plack::App::BeanstalkConsole - A web application that provides access to Beanstalk statistics and tools
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -111,14 +114,6 @@ L<Plack::App::PHPCGIFile>.)
 The C<php-cgi> binary must be available in C<$PATH>.  In newer versions of
 PHP, this is is normally installed as part of the main PHP installation.
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Plack-App-BeanstalkConsole>
-(or L<bug-Plack-App-BeanstalkConsole@rt.cpan.org|mailto:bug-Plack-App-BeanstalkConsole@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =for stopwords beanstalkd
@@ -143,11 +138,24 @@ L<beanstalkd|http://kr.github.com/beanstalkd>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Plack-App-BeanstalkConsole>
+(or L<bug-Plack-App-BeanstalkConsole@rt.cpan.org|mailto:bug-Plack-App-BeanstalkConsole@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<https://groups.google.com/forum/#!forum/psgi-plack>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#plack> on C<irc.perl.org>|irc://irc.perl.org/#plack>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
